@@ -96,7 +96,7 @@ if __name__ == "__main__":
     
     # get a cache
     cache = apt.Cache(rootdir=os.path.abspath(aptbasedir))
-    cache.update(apt.progress.TextFetchProgress())
+    cache.update(apt.progress.text.AcquireProgress())
     cache.open(apt.progress.OpProgress())
 
     # now test if we can install stuff
@@ -143,7 +143,7 @@ if __name__ == "__main__":
         pkg_failed = False
 
         # skip stuff in the ubuntu-minimal that we can't install or upgrade
-        if pkg.isInstalled and not pkg.isUpgradable:
+        if pkg.is_installed and not pkg.is_upgradable:
             continue
 
         # skip blacklisted pkg names
