@@ -7,6 +7,25 @@ import sys
 import gettext
 import errno
 
+APPORT_WHITELIST = [
+    "apt.log",
+    "apt-term.log",
+    "history.log",
+    "lspci.txt",
+    "main.log",
+    "term.log",
+    "screenlog.0",
+    "xorg_fixup.log",
+    ]
+
+
+def _apport_append_logfiles(report, logdir="/var/log/dist-upgrade/"):
+    for fname in APPORT_WHITELIST:
+        f = os.path.join(logdir, fname)
+        if not os.path.isfile(f) or os.path.getsize(f) == 0:
+            continue
+        report[f.replace(".","").replace("-","")] = (open(f), )
+
 def apport_crash(type, value, tb):
     logging.debug("running apport_crash()")
     try:
@@ -21,8 +40,7 @@ def apport_crash(type, value, tb):
     # now add the files in /var/log/dist-upgrade/*
     if os.path.exists('/var/crash/_usr_bin_update-manager.0.crash'):
         report = Report()
-        for f in os.listdir("/var/log/dist-upgrade/"):
-            report[f.replace(".","").replace("-","")] = (open(os.path.join("/var/log/dist-upgrade",f)), )
+        _apport_append_logfiles(report)
         report.add_to_existing('/var/crash/_usr_bin_update-manager.0.crash')
     return True
 
@@ -40,10 +58,14 @@ def apport_pkgfailure(pkg, errormsg):
         return False
 
     if os.path.exists(s):
+        args = [s, "-p", pkg]
+        for fname in APPORT_WHITELIST:
+            args.extend(["-l", os.path.join(LOGDIR, fname)])
         try:
-            p = subprocess.Popen([s,"-p",pkg,"-l",LOGDIR], stdin=subprocess.PIPE)
+            p = subprocess.Popen(args, stdin=subprocess.PIPE)
             p.stdin.write("ErrorMessage: %s\n" % errormsg)
             p.stdin.close()
+            #p.wait()
         except Exception, e:
             logging.warning("Failed to run apport (%s)" % e)
             return False
@@ -58,10 +80,18 @@ def run_apport():
     if "DISPLAY" in os.environ:
         for p in ["/usr/share/apport/apport-gtk", "/usr/share/apport/apport-qt"]:
             if os.path.exists(p):
-                ret = subprocess.call(p)
+                ret = -1
+                try:
+                    ret = subprocess.call(p)
+                except Exception, e:
+                    logging.exception("Unable to launch '%s' " % p)
                 return (ret == 0)
     elif os.path.exists("/usr/bin/apport-cli"):
-        return (subprocess.call("/usr/bin/apport-cli") == 0)
+        try:
+            return (subprocess.call("/usr/bin/apport-cli") == 0)
+        except Exception, e:
+            logging.exception("Unable to launch '/usr/bin/apport-cli'")
+            return False
     logging.debug("can't find apport")
     return False
 
