@@ -41,6 +41,8 @@ from DistUpgradeGettext import ngettext
 from DistUpgradeConfigParser import DistUpgradeConfig
 from DistUpgradeView import FuzzyTimeToStr
 
+from utils import inside_chroot
+
 class CacheException(Exception):
     pass
 class CacheExceptionLockingFailed(CacheException):
@@ -225,7 +227,7 @@ class MyCache(apt.Cache):
         self.unlockListsDir()
         res = apt.Cache.update(self, fprogress)
         self.lockListsDir()
-        if fprogress.release_file_download_error:
+        if fprogress and fprogress.release_file_download_error:
             # FIXME: not ideal error message, but we just reuse a 
             #        existing one here to avoid a new string
             raise IOError(_("The server may be overloaded"))
@@ -279,7 +281,7 @@ class MyCache(apt.Cache):
         """ create a snapshot of the current changes """
         self.to_install = []
         self.to_remove = []
-        for pkg in self.getChanges():
+        for pkg in self.get_changes():
             if pkg.marked_install or pkg.marked_upgrade:
                 self.to_install.append(pkg.name)
             if pkg.marked_delete:
@@ -347,7 +349,7 @@ class MyCache(apt.Cache):
                 return False
         return True
 
-    def markInstall(self, pkg, reason=""):
+    def mark_install(self, pkg, reason=""):
         logging.debug("Installing '%s' (%s)" % (pkg, reason))
         if self.has_key(pkg):
             self[pkg].mark_install()
@@ -356,7 +358,7 @@ class MyCache(apt.Cache):
                 #raise (SystemError, "Installing '%s' failed" % pkg)
                 return False
         return True
-    def markUpgrade(self, pkg, reason=""):
+    def mark_upgrade(self, pkg, reason=""):
         logging.debug("Upgrading '%s' (%s)" % (pkg, reason))
         if self.has_key(pkg) and self[pkg].is_installed:
             self[pkg].mark_upgrade()
@@ -364,11 +366,11 @@ class MyCache(apt.Cache):
                 logging.error("Upgrading '%s' failed" % pkg)
                 return False
         return True
-    def markRemove(self, pkg, reason=""):
+    def mark_remove(self, pkg, reason=""):
         logging.debug("Removing '%s' (%s)" % (pkg, reason))
         if self.has_key(pkg):
             self[pkg].mark_delete()
-    def markPurge(self, pkg, reason=""):
+    def mark_purge(self, pkg, reason=""):
         logging.debug("Purging '%s' (%s)" % (pkg, reason))
         if self.has_key(pkg):
             self._depcache.mark_delete(self[pkg]._pkg,True)
@@ -377,7 +379,7 @@ class MyCache(apt.Cache):
         if (self.has_key(pkgname)
             and self[pkgname].is_installed
             and self[pkgname].marked_delete):
-            self.markInstall(pkgname, reason)
+            self.mark_install(pkgname, reason)
 
     def keepInstalledRule(self):
         """ run after the dist-upgrade to ensure that certain
@@ -412,10 +414,10 @@ class MyCache(apt.Cache):
 
     def postUpgradeRule(self):
         " run after the upgrade was done in the cache "
-        for (rule, action) in [("Install", self.markInstall),
-                               ("Upgrade", self.markUpgrade),
-                               ("Remove", self.markRemove),
-                               ("Purge", self.markPurge)]:
+        for (rule, action) in [("Install", self.mark_install),
+                               ("Upgrade", self.mark_upgrade),
+                               ("Remove", self.mark_remove),
+                               ("Purge", self.mark_purge)]:
             # first the global list
             for pkg in self.config.getlist("Distro","PostUpgrade%s" % rule):
                 action(pkg, "Distro PostUpgrade%s rule" % rule)
@@ -480,7 +482,7 @@ class MyCache(apt.Cache):
             # check if a binary driver is installed now
             for oldDriver in nv.oldPackages:
                 if self.has_key(oldDriver) and self[oldDriver].is_installed:
-                    self.markRemove(oldDriver, "old nvidia driver")
+                    self.mark_remove(oldDriver, "old nvidia driver")
                     break
             else:
                 logging.info("no old nvidia driver installed, installing no new")
@@ -529,11 +531,11 @@ class MyCache(apt.Cache):
             if self[kernel].is_installed or self[kernel].marked_install:
                 logging.debug("%s kernel already installed" % kernel)
                 if self[kernel].is_upgradable and not self[kernel].marked_upgrade:
-                    self.markUpgrade(kernel, "Upgrading kernel from base-installer")
+                    self.mark_upgrade(kernel, "Upgrading kernel from base-installer")
                 return 
         # if we have not found a kernel yet, use the first one that installs
         for kernel in kernels:
-            if self.markInstall(kernel, "Selecting new kernel from base-installer"):
+            if self.mark_install(kernel, "Selecting new kernel from base-installer"):
                 return
 
     def checkForKernel(self):
@@ -573,7 +575,7 @@ class MyCache(apt.Cache):
                 not (pkg.is_installed or pkg.marked_install) and
                 not pkg.name in removeEssentialOk and
                 pkg.priority in need):
-                self.markInstall(pkg.name, "priority in required set '%s' but not scheduled for install" % need)
+                self.mark_install(pkg.name, "priority in required set '%s' but not scheduled for install" % need)
 
     # FIXME: make this a decorator (just like the withResolverLog())
     def updateGUI(self, view, lock):
@@ -604,8 +606,12 @@ class MyCache(apt.Cache):
             # see if our KeepInstalled rules are honored
             self.keepInstalledRule()
 
-            # check if we got a new kernel
-            self.checkForKernel()
+            # check if we got a new kernel (if we are not inside a 
+            # chroot)
+            if inside_chroot():
+                logging.warn("skipping kernel checks because we run inside a chroot")
+            else:
+                self.checkForKernel()
 
             # check for nvidia stuff
             self.checkForNvidia()
@@ -662,21 +668,22 @@ class MyCache(apt.Cache):
         
         # check the trust of the packages that are going to change
         untrusted = []
-        for pkg in self.getChanges():
+        for pkg in self.get_changes():
             if pkg.marked_delete:
                 continue
             # special case because of a bug in pkg.candidateOrigin
-            if pkg.markedDowngrade:
+            if pkg.marked_downgrade:
                 for ver in pkg._pkg.version_list:
                     # version is lower than installed one
-                    if apt_pkg.VersionCompare(ver.VerStr, pkg.installedVersion) < 0:
-                        for (verFileIter,index) in ver.FileList:
+                    if apt_pkg.version_compare(
+                        ver.ver_str, pkg.installed.version) < 0:
+                        for (verFileIter, index) in ver.file_list:
                             indexfile = pkg._list.find_index(verFileIter)
-                            if indexfile and not indexfile.IsTrusted:
+                            if indexfile and not indexfile.is_trusted:
                                 untrusted.append(pkg.name)
                                 break
                 continue
-            origins = pkg.candidateOrigin
+            origins = pkg.candidate.origins
             trusted = False
             for origin in origins:
                 #print origin
@@ -715,7 +722,7 @@ class MyCache(apt.Cache):
         """
         removeEssentialOk = self.config.getlist("Distro","RemoveEssentialOk")
         # check changes
-        for pkg in self.getChanges():
+        for pkg in self.get_changes():
             if pkg.marked_delete and self._inRemovalBlacklist(pkg.name):
                 logging.debug("The package '%s' is marked for removal but it's in the removal blacklist", pkg.name)
                 raise SystemError, _("The package '%s' is marked for removal but it is in the removal blacklist.") % pkg.name
@@ -745,11 +752,11 @@ class MyCache(apt.Cache):
         if ver is None:
             print "No candidate ver: ", pkg.name
             return False
-        if ver.FileList is None:
+        if ver.file_list is None:
             print "No FileList for: %s " % self._pkg.Name()
             return False
-        f, index = ver.FileList.pop(0)
-        pkg._pcache._records.Lookup((f, index))
+        f, index = ver.file_list.pop(0)
+        pkg._pcache._records.lookup((f, index))
         return True
 
     @property
@@ -760,7 +767,7 @@ class MyCache(apt.Cache):
             if not self._lookupPkgRecord(pkg):
                 logging.debug("no PkgRecord found for '%s', skipping " % pkg.name)
                 continue
-            for line in pkg._pcache._records.Record.split("\n"):
+            for line in pkg._pcache._records.record.split("\n"):
                 if line.startswith("Task:"):
                     for task in (line[len("Task:"):]).split(","):
                         task = task.strip()
@@ -783,10 +790,10 @@ class MyCache(apt.Cache):
             if pkg.marked_install or pkg.is_installed:
                 continue
             self._lookupPkgRecord(pkg)
-            if not (hasattr(pkg._pcache._records,"Record") and pkg._pcache._records.Record):
+            if not (hasattr(pkg._pcache._records,"record") and pkg._pcache._records.record):
                 logging.warning("can not find Record for '%s'" % pkg.name)
                 continue
-            for line in pkg._pcache._records.Record.split("\n"):
+            for line in pkg._pcache._records.record.split("\n"):
                 if line.startswith("Task:"):
                     for task in (line[len("Task:"):]).split(","):
                         task = task.strip()
@@ -830,10 +837,12 @@ class MyCache(apt.Cache):
                     self[key].is_installed and
                     self[key].is_upgradable):
                     logging.debug("Marking '%s' for upgrade" % key)
-                    self[key].markUpgrade()
+                    self[key].mark_upgrade()
             except SystemError, e:
-                logging.debug("Can't mark '%s' for upgrade (%s)" % (key,e))
-                raise SystemError, _("Can not mark '%s' for upgrade") % key
+                # warn here, but don't fail, its possible that meta-packages
+                # conflict (like ubuntu-desktop vs xubuntu-desktop) LP: #775411
+                logging.warn("Can't mark '%s' for upgrade (%s)" % (key,e))
+
         # check if we have a meta-pkg, if not, try to guess which one to pick
         if not metaPkgInstalled():
             logging.debug("none of the '%s' meta-pkgs installed" % metapkgs)
@@ -911,7 +920,7 @@ class MyCache(apt.Cache):
             self[pkgname].markDelete(purge=purge)
             self.view.processEvents()
             #logging.debug("marking '%s' for removal" % pkgname)
-            for pkg in self.getChanges():
+            for pkg in self.get_changes():
                 if (pkg.name not in remove_candidates or 
                       pkg.name in foreign_pkgs or 
                       self._inRemovalBlacklist(pkg.name)):
@@ -972,7 +981,7 @@ class MyCache(apt.Cache):
                 self._depcache.is_auto_installed(pkg._pkg) or
                 pkg.marked_delete):
                 continue
-            installed_demotions.add(pkg.name)
+            installed_demotions.add(pkg)
         return list(installed_demotions)
 
     def _getForeignPkgs(self, allowed_origin, fromDist, toDist):
@@ -1145,5 +1154,5 @@ if __name__ == "__main__":
         c.create_snapshot()
         c.installedTasks
         c.installTasks(["ubuntu-desktop"])
-        print c.getChanges()
+        print c.get_changes()
         c.restore_snapshot()
