@@ -24,12 +24,13 @@ pygtk.require('2.0')
 import gtk
 
 from ReleaseNotesViewer import ReleaseNotesViewer
-from Common.utils import *
+from Core.utils import *
 from Core.DistUpgradeFetcherCore import DistUpgradeFetcherCore
 from gettext import gettext as _
 import urllib2
 import dbus
 import os
+import socket
 
 
 class DistUpgradeFetcherGtk(DistUpgradeFetcherCore):
@@ -46,7 +47,10 @@ class DistUpgradeFetcherGtk(DistUpgradeFetcherCore):
         inhibit_sleep()
         # now run it with sudo
         if os.getuid() != 0:
-            os.execv("/usr/bin/gksu",["gksu",self.script])
+            os.execv("/usr/bin/gksu",["gksu",
+                                      "--desktop","/usr/share/applications/update-manager.desktop",
+                                      "--",
+                                      self.script]+self.run_options)
         else:
             os.execv(self.script,[self.script]+self.run_options)
         # we shouldn't come to this point, but if we do, undo our
@@ -65,7 +69,9 @@ class DistUpgradeFetcherGtk(DistUpgradeFetcherCore):
           # download/display the release notes
           # FIXME: add some progress reporting here
           res = gtk.RESPONSE_CANCEL
+          timeout = socket.getdefaulttimeout()
           try:
+              socket.setdefaulttimeout(5)
               release_notes = urllib2.urlopen(uri)
               notes = release_notes.read()
               textview_release_notes = ReleaseNotesViewer(notes)
@@ -96,12 +102,13 @@ class DistUpgradeFetcherGtk(DistUpgradeFetcherCore):
               dialog.format_secondary_text(secondary);
               dialog.run()
               dialog.destroy()
+          socket.setdefaulttimeout(timeout)              
           self.window_main.set_sensitive(True)
           self.window_main.window.set_cursor(None)
           # user clicked cancel
-          if res == gtk.RESPONSE_CANCEL:
-              return False
-      return True
+          if res == gtk.RESPONSE_OK:
+              return True
+      return False
 
 if __name__ == "__main__":
     error(None, "summary","message")
