@@ -1,6 +1,6 @@
 # UpdateManager.py 
 #  
-#  Copyright (c) 2004-2008 Canonical
+#  Copyright (c) 2004-2010 Canonical
 #                2004 Michiel Sikkes
 #                2005 Martin Willemoes Hansen
 #                2010 Mohamed Amine IL Idrissi
@@ -9,6 +9,7 @@
 #          Michael Vogt <mvo@debian.org>
 #          Martin Willemoes Hansen <mwh@sysrq.dk>
 #          Mohamed Amine IL Idrissi <ilidrissiamine@gmail.com>
+#          Alex Launi <alex.launi@canonical.com>
 # 
 #  This program is free software; you can redistribute it and/or 
 #  modify it under the terms of the GNU General Public License as 
@@ -99,26 +100,80 @@ from MetaReleaseGObject import MetaRelease
 REBOOT_REQUIRED_FILE = "/var/run/reboot-required"
 
 # NetworkManager enums
-NM_STATE_UNKNOWN = 0
-NM_STATE_ASLEEP = 1
-NM_STATE_CONNECTING = 2
-NM_STATE_CONNECTED = 3
-NM_STATE_DISCONNECTED = 4
+from Core.roam import NetworkManagerHelper
 
-class UpdateManagerDbusControler(dbus.service.Object):
+def show_dist_no_longer_supported_dialog(parent=None):
+    """ show a no-longer-supported dialog """
+    msg = "<big><b>%s</b></big>\n\n%s" % (
+        _("Your Ubuntu release is not supported anymore."),
+        _("You will not get any further security fixes or critical "
+          "updates. "
+          "Please upgrade to a later version of Ubuntu Linux."))
+    dialog = gtk.MessageDialog(parent, 0, gtk.MESSAGE_WARNING,
+                               gtk.BUTTONS_CLOSE,"")
+    dialog.set_title("")
+    dialog.set_markup(msg)
+    button = gtk.LinkButton(uri="http://www.ubuntu.com/releaseendoflife",
+                            label=_("Upgrade information"))
+    button.show()
+    dialog.get_content_area().pack_end(button)
+    # this data used in the test to get the dialog
+    if parent:
+        parent.set_data("no-longer-supported-nag", dialog)
+    dialog.run()
+    dialog.destroy()
+    if parent:
+        parent.set_data("no-longer-supported-nag", None)
+
+
+class UpdateManagerDbusController(dbus.service.Object):
     """ this is a helper to provide the UpdateManagerIFace """
     def __init__(self, parent, bus_name,
                  object_path='/org/freedesktop/UpdateManagerObject'):
         dbus.service.Object.__init__(self, bus_name, object_path)
         self.parent = parent
+        self.alert_watcher = AlertWatcher ()
+        self.alert_watcher.connect("network-alert", self._on_network_alert)
+        self.connected = False
 
     @dbus.service.method('org.freedesktop.UpdateManagerIFace')
     def bringToFront(self):
         self.parent.window_main.present()
         return True
 
+    @dbus.service.method('org.freedesktop.UpdateManagerIFace')
+    def update(self):
+        try:
+            self.alert_watcher.check_alert_state ()
+            self.parent.invoke_manager(UPDATE)
+            return self.connected
+        except:
+            return False
+
+    @dbus.service.method('org.freedesktop.UpdateManagerIFace')
+    def upgrade(self):
+        try:
+            self.parent.cache.checkFreeSpace()
+            self.parent.invoke_manager(INSTALL)
+            return True
+        except:
+            return False
+
+    @dbus.service.signal('org.freedesktop.UpdateManagerIFace', 'b')
+    def updated(self, success):
+        pass	
+
+    def _on_network_alert(self, watcher, state):
+        if state == NetworkManagerHelper.NM_STATE_CONNECTED:
+            self.connected = True
+        else:
+            self.connected = False
+
 class UpdateManager(SimpleGtkbuilderApp):
 
+  # how many days until u-m warns about manual pressing "check"
+  NO_UPDATE_WARNING_DAYS = 7
+
   def __init__(self, datadir, options):
     self.setupDbus()
     gtk.window_set_default_icon_name("update-manager")
@@ -141,6 +196,7 @@ class UpdateManager(SimpleGtkbuilderApp):
     self.window_main.grab_focus()
     self.button_close.grab_focus()
     self.dl_size = 0
+    self.connected = True
 
     # create text view
     self.textview_changes = ChangelogViewer()
@@ -239,6 +295,7 @@ class UpdateManager(SimpleGtkbuilderApp):
     self.alert_watcher = AlertWatcher()
     self.alert_watcher.connect("network-alert", self._on_network_alert)
     self.alert_watcher.connect("battery-alert", self._on_battery_alert)
+    self.alert_watcher.connect("network-3g-alert", self._on_network_3g_alert)
 
   def on_initial_focus_in(self, widget, event):
       """callback run on initial focus-in (if started unmapped)"""
@@ -294,7 +351,7 @@ class UpdateManager(SimpleGtkbuilderApp):
     except dbus.DBusException, e:
          #print "no listening object (%s) "% e
          bus_name = dbus.service.BusName('org.freedesktop.UpdateManager',bus)
-         self.dbusControler = UpdateManagerDbusControler(self, bus_name)
+         self.dbusController = UpdateManagerDbusController(self, bus_name)
 
 
   def on_checkbutton_reminder_toggled(self, checkbutton):
@@ -371,10 +428,17 @@ class UpdateManager(SimpleGtkbuilderApp):
 
     changes_buffer = self.textview_changes.get_buffer()
     
-    # check if we have the changes already
+    # check if we have the changes already and if so, display them 
+    # (even if currently disconnected)
     if self.cache.all_changes.has_key(name):
       changes = self.cache.all_changes[name]
       self.set_changes_buffer(changes_buffer, changes[0], name, changes[1])
+    # if not connected, do not even attempt to get the changes
+    elif not self.connected:
+        changes_buffer.set_text(
+            _("No network connection detected, you can not download "
+              "changelog information."))
+    # else, get it from the entwork
     else:
       if self.expander_details.get_expanded():
         lock = thread.allocate_lock()
@@ -509,21 +573,37 @@ class UpdateManager(SimpleGtkbuilderApp):
           self.hbox_downsize.show()
           self.vbox_alerts.show()
 
+  def _get_last_apt_get_update_hours(self):
+      """
+      Return the number of hours since the last successful apt-get update
+      
+      If the date is unknown, return "None"
+      """
+      if not os.path.exists("/var/lib/apt/periodic/update-success-stamp"):
+          return None
+      # calculate when the last apt-get update (or similar operation)
+      # was performed
+      mtime = os.stat("/var/lib/apt/periodic/update-success-stamp")[stat.ST_MTIME]
+      ago_hours = int((time.time() - mtime) / (60*60) )
+      return ago_hours
+
   def _get_last_apt_get_update_text(self):
       """
       return a human readable string with the information when
       the last apt-get update was run
       """
-      if not os.path.exists("/var/lib/apt/periodic/update-success-stamp"):
+      ago_hours = self._get_last_apt_get_update_hours()
+      if ago_hours is None:
           return _("It is unknown when the package information was "
                    "updated last. Please try clicking on the 'Check' "
                    "button to update the information.")
-      # calculate when the last apt-get update (or similar operation)
-      # was performed
-      mtime = os.stat("/var/lib/apt/periodic/update-success-stamp")[stat.ST_MTIME]
-      ago_days = int( (time.time() - mtime) / (24*60*60))
-      ago_hours = int((time.time() - mtime) / (60*60) )
-      if ago_days > 0:
+      ago_days = int( ago_hours / 24 )
+      if ago_days > self.NO_UPDATE_WARNING_DAYS:
+	  return _("The package information was last updated %(days_ago)s "
+                   "days ago.\n"
+                   "Press the 'Check' button below to check for new software "
+                   "updates.") % { "days_ago" : ago_days, }
+      elif ago_days > 0:
           return ngettext("The package information was last updated %(days_ago)s day ago.",
                           "The package information was last updated %(days_ago)s days ago.",
                           ago_days) % { "days_ago" : ago_days, }
@@ -565,6 +645,8 @@ class UpdateManager(SimpleGtkbuilderApp):
           self.textview_descr.get_buffer().set_text("")
           if self._get_last_apt_get_update_text() is not None:
               text_label_main = self._get_last_apt_get_update_text()
+	      if self._get_last_apt_get_update_hours() > self.NO_UPDATE_WARNING_DAYS*24:
+			text_header = "<big><b>%s</b></big>"  % _("Software updates may be available for your computer.")
           # add timer to ensure we update the information when the 
           # last package count update was performed
           glib.timeout_add_seconds(10, self.update_last_updated_text)
@@ -573,11 +655,17 @@ class UpdateManager(SimpleGtkbuilderApp):
           firstrun = self.gconfclient.get_bool("/apps/update-manager/first_run")
           if firstrun:
               text_header = "<big><b>%s</b></big>" % _("Welcome to Ubuntu")
-              text_label_main = _("These software updates have been issued since Ubuntu was released. If you don't want to install them now, choose \"Update Manager\" from the Administration Menu later.")
+              if is_unity_running():
+                  text_label_main = _("These software updates have been issued since Ubuntu was released. If you don't want to install them now, choose \"Update Manager\" from Applications later.")
+              else:   
+                  text_label_main = _("These software updates have been issued since Ubuntu was released. If you don't want to install them now, choose \"Update Manager\" from the Administration Menu later.")
               self.gconfclient.set_bool("/apps/update-manager/first_run", False)
           else:
               text_header = "<big><b>%s</b></big>" % _("Software updates are available for this computer")
-              text_label_main = _("If you don't want to install them now, choose \"Update Manager\" from the Administration menu later.")
+              if is_unity_running():
+                  text_label_main = _("If you don't want to install them now, choose \"Update Manager\" from Applications later.")
+              else:
+                  text_label_main = _("If you don't want to install them now, choose \"Update Manager\" from the Administration menu later.")
           self.notebook_details.set_sensitive(True)
           self.treeview_update.set_sensitive(True)
           self.button_install.grab_default()
@@ -662,7 +750,18 @@ class UpdateManager(SimpleGtkbuilderApp):
                                    "/org/gnome/SessionManager")
         iface = dbus.Interface(proxy_obj, "org.gnome.SessionManager")
         iface.RequestReboot()
-        # FIXME: try sesion restart with hal?
+    except dbus.DBusException:
+        self._request_reboot_via_consolekit()
+    except:
+        pass
+
+  def _request_reboot_via_consolekit(self):
+    try:
+        bus = dbus.SystemBus()
+        proxy_obj = bus.get_object("org.freedesktop.ConsoleKit",
+                                   "/org/freedesktop/ConsoleKit/Manager")
+        iface = dbus.Interface(proxy_obj, "org.freedesktop.ConsoleKit.Manager")
+        iface.Restart()
     except dbus.DBusException, e:
         pass
 
@@ -697,7 +796,9 @@ class UpdateManager(SimpleGtkbuilderApp):
                 pkgs_upgrade.append(pkg.name)
         self.install_backend.commit(pkgs_install, pkgs_upgrade, close_on_done)
 
-  def _on_backend_done(self, backend, action, authorized):
+  def _on_backend_done(self, backend, action, authorized, success):
+    if (action == UPDATE):
+        self.dbusController.updated(success)
     # check if there is a new reboot required notification
     if (action == INSTALL and
         os.path.exists(REBOOT_REQUIRED_FILE)):
@@ -717,17 +818,24 @@ class UpdateManager(SimpleGtkbuilderApp):
   def _on_network_alert(self, watcher, state):
       # do not set the buttons to sensitive/insensitive until NM
       # can deal with dialup connections properly
-      if state == NM_STATE_CONNECTING:
+      if state == NetworkManagerHelper.NM_STATE_CONNECTING:
           self.label_offline.set_text(_("Connecting..."))
           #self.button_reload.set_sensitive(False)
           self.refresh_updates_count()
           self.hbox_offline.show()
           self.vbox_alerts.show()
-      elif state == NM_STATE_CONNECTED:
+          self.connected = False
+      # in doubt (STATE_UNKNOWN), assume connected
+      elif state in (NetworkManagerHelper.NM_STATE_CONNECTED,
+                     NetworkManagerHelper.NM_STATE_UNKNOWN):
           #self.button_reload.set_sensitive(True)
           self.refresh_updates_count()
           self.hbox_offline.hide()
+          self.connected = True
+          # trigger re-showing the current app to get changelog info (if needed)
+          self.on_treeview_update_cursor_changed(self.treeview_update)
       else:
+          self.connected = False
           self.label_offline.set_text(_("You may not be able to check for updates or download new updates."))
           #self.button_reload.set_sensitive(False)
           self.refresh_updates_count()
@@ -741,6 +849,18 @@ class UpdateManager(SimpleGtkbuilderApp):
       else:
           self.hbox_battery.hide()    
 
+  def _on_network_3g_alert(self, watcher, on_3g, is_roaming):
+      #print "on 3g: %s; roaming: %s" % (on_3g, is_roaming)
+      if is_roaming:
+          self.hbox_roaming.show()
+          self.hbox_on_3g.hide()
+      elif on_3g:
+          self.hbox_on_3g.show()
+          self.hbox_roaming.hide()
+      else:
+          self.hbox_on_3g.hide()
+          self.hbox_roaming.hide()
+
   def row_activated(self, treeview, path, column):
       iter = self.store.get_iter(path)
       pkg = self.store.get_value(iter, LIST_PKG)
@@ -809,6 +929,7 @@ class UpdateManager(SimpleGtkbuilderApp):
     self.label_main_details.set_size_request(width - border_space ,-1)
     self.label_header.set_size_request(width - border_space,-1)
     self.label_downsize.set_size_request(width - border_space,-1)
+    self.label_roaming.set_size_request(width - border_space,-1)
 
   def exit(self):
     """ exit the application, save the state """
@@ -864,9 +985,14 @@ class UpdateManager(SimpleGtkbuilderApp):
     self.list = UpdateList(self)
     while gtk.events_pending():
         gtk.main_iteration()
+
     # fill them again
     try:
-        self.list.update(self.cache)
+        # This is  a quite nasty hack to stop the initial update 
+        if not self.options.no_update:
+            self.list.update(self.cache)
+        else:
+            self.options.no_update = False
     except SystemError, e:
         msg = ("<big><b>%s</b></big>\n\n%s\n'%s'" %
                (_("Could not calculate the upgrade"),
@@ -922,21 +1048,7 @@ class UpdateManager(SimpleGtkbuilderApp):
     return False
 
   def dist_no_longer_supported(self, meta_release):
-    msg = "<big><b>%s</b></big>\n\n%s" % \
-          (_("Your Ubuntu release is not supported anymore"),
-	   _("You will not get any further security fixes or critical "
-             "updates. "
-             "Please Upgrade to a later version of Ubuntu Linux."))
-    dialog = gtk.MessageDialog(self.window_main, 0, gtk.MESSAGE_WARNING,
-                               gtk.BUTTONS_CLOSE,"")
-    dialog.set_title("")
-    dialog.set_markup(msg)
-    button = gtk.LinkButton(_("Upgrade information"))
-    button.set_uri("http://www.ubuntu.com/getubuntu/upgrading")
-    button.show()
-    dialog.get_content_area().pack_end(button)
-    dialog.run()
-    dialog.destroy()
+    show_dist_no_longer_supported_dialog(self.window_main)
 
   def error(self, summary, details):
       " helper function to display a error message "
