@@ -6,7 +6,7 @@
 
 set -e
 
-DIST=karmic
+DIST=natty
 BASEDIR=./apt
 
 APT_OPTS="\
